# flask_mico

**developing** 正在使用`flask_mico`投入生产中，等待我的好消息...

## 添加有趣的功能

- `error`
- `settings`
- `middleware`
- `ApiView`
- `urls`
- `validator`

## Installation

`pip install flask_mico`

## Usage

- start project

  `startproject [project name] [project dirname]`

## Todo

- [ ] 在 `settings.py` 中添加自定义命令
